'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var tComm = require('t-comm');
var shared = require('@plugin-light/shared');

const IGNORE_FILE_LIST = [
    'common/vendor.js',
    'common/runtime.js',
    'common/main.js',
];
const isIgnore = (str) => IGNORE_FILE_LIST.find(item => str.startsWith(item));
function replaceSource(source, adapterDirs) {
    const replaceReg = new RegExp(`\\.\\./\\.\\./(${adapterDirs.join('|')})(/)(.+?)('|"|/)`, 'g');
    source = source.replace(replaceReg, (...args) => {
        const { 0: origin, 1: localName, 2: slash, 3: innerDir, 4: slashOrQuote } = args;
        const dir = `${localName}${slash}${innerDir}`;
        if (isIgnore(dir)) {
            return origin;
        }
        return `${localName}${slash}${innerDir}${slashOrQuote}`;
    });
    return source;
}

tComm.replaceAllPolyfill();
class TransferLocalFilePlugin {
    options;
    constructor(options) {
        this.options = options;
        shared.createLogDir();
    }
    apply(compiler) {
        const { isModifyRef = false } = this.options || {};
        compiler.hooks.emit.tap('moveComponentPlugin', (compilation) => {
            const { assets } = compilation;
            this.moveComp(assets);
            if (isModifyRef) {
                this.modifyRef(assets);
            }
            shared.saveJsonToLog(Object.keys(assets), 'transfer-local-file.assets.json');
        });
    }
    moveComp(assets) {
        const { adapterDirs = [] } = this.options || {};
        const movePrefixList = adapterDirs.map(item => `../../${item}`);
        const isMoveDir = (key, dirs) => !!dirs.find(item => key.startsWith(item));
        const getNewKey = (key) => key.replace(/^\.\.\/\.\.\//, '');
        for (const key of Object.keys(assets)) {
            if (isMoveDir(key, movePrefixList)) {
                const newKey = getNewKey(key);
                assets[newKey] = assets[key];
                delete assets[key];
            }
        }
    }
    modifyRef(assets) {
        const { adapterDirs = [] } = this.options || {};
        for (const key of Object.keys(assets)) {
            const value = assets[key];
            if (key.endsWith('.js') || key.endsWith('.json')) {
                let source = value.source().toString();
                source = replaceSource(source, adapterDirs);
                shared.updateAssetSource(assets, key, source);
            }
        }
    }
}

exports.TransferLocalFilePlugin = TransferLocalFilePlugin;
